gsprofilesrv_plat/settings_framework_api/inc/GSParentPlugin.h
branchRCL_3
changeset 11 23553eb4e470
parent 8 f62c3a3d66b8
--- a/gsprofilesrv_plat/settings_framework_api/inc/GSParentPlugin.h	Fri Mar 12 15:43:47 2010 +0200
+++ b/gsprofilesrv_plat/settings_framework_api/inc/GSParentPlugin.h	Mon Mar 15 12:41:46 2010 +0200
@@ -229,6 +229,26 @@
         * @since S60 v3.1
         */
         void SetMiddleSoftKeyLabelTextL( const TPtr aMskLabel, const TInt aCommandId );
+        
+        /**
+        * represent the position of ListBox
+        */
+        struct TListBoxPosition
+            {
+            /**
+            * The three items are all set to -1 as an initial value because their legal
+            * value should be no less than 0.
+            */
+        	inline void Reset()
+        	    {
+        	 	iCurrentItemIndex = -1;
+        		iItemOffsetInPixels = -1;
+        		iTopItemIndex = -1;
+        		}
+        	TInt iCurrentItemIndex;
+        	TInt iItemOffsetInPixels;
+        	TInt iTopItemIndex;
+        	};
 
     public: // From MGSChildViewManager
 
@@ -330,11 +350,11 @@
         TUid iTopPluginUid;
         
         //keep the exact position of the listbox including current item index,
-        //iVerticalOffset and  TopItemindex
-        RArray<TInt> iPosition;
+        //ItemOffsetInPixels and  TopItemindex
+        TListBoxPosition iPosition;
         
         //record the screen mode, portrait/landscape
-        TBool iScreenMode;
+        TBool iIsLandscapeOrientation;
 };